# Version Check

Core Functionality:
- Look for requirements*.txt files in your working directory and check for updates.
- Prompt to confirm each update with an upstream url.

## Install

Install this helper script into your virtual environment. Add this to your requirements.txt file:

```
requirementscheck @ git+https://github.com/bbilly1/requirementscheck.git
```
